/*!
 * Enterprise Web Components v1.13.2 (chunk/code split version all components)
 * Copyright (c) 2025 Infor
 */
import {
  stripHTML
} from "./ids-chunk-Q3E5P243-full.js";
import {
  attributes
} from "./ids-chunk-SCUDQYUW-full.js";

// src/mixins/ids-color-variant-mixin/ids-color-variant-mixin.ts
var IdsColorVariantMixin = (superclass) => class extends superclass {
  constructor(...args) {
    super(...args);
  }
  connectedCallback() {
    super.connectedCallback();
    if (this.colorVariant) this.#refreshColorVariant(null, this.colorVariant);
  }
  static get attributes() {
    return [
      ...superclass.attributes,
      attributes.COLOR_VARIANT
    ];
  }
  /**
   * @returns {Array<string>} List of available color variants for this component
   */
  colorVariants = [];
  /**
   * @returns {string|null} the name of the color variant currently applied
   */
  get colorVariant() {
    return this.getAttribute(attributes.COLOR_VARIANT);
  }
  /**
   * @param {string | null} val the name of the color variant to be applied
   */
  set colorVariant(val) {
    const safeValue = val ? stripHTML(val) : "";
    const currentValue = this.colorVariant;
    if (this.colorVariants.includes(safeValue)) {
      this.setAttribute(attributes.COLOR_VARIANT, `${safeValue}`);
    } else {
      this.removeAttribute(attributes.COLOR_VARIANT);
    }
    if (!safeValue || currentValue === safeValue) return;
    this.#refreshColorVariant(currentValue, safeValue);
  }
  /**
   * Refreshes the component's color variant state, driven by
   * a CSS class on the WebComponent's `container` element
   * @param {string} oldVariantName the variant name to "remove" from the style
   * @param {string} newVariantName the variant name to "add" to the style
   * @returns {void}
   */
  #refreshColorVariant(oldVariantName, newVariantName) {
    if (!this.container) {
      return;
    }
    const cl = this.container?.classList;
    if (oldVariantName) cl?.remove(`color-variant-${oldVariantName}`);
    if (newVariantName) cl?.add(`color-variant-${newVariantName}`);
    if (typeof this.onColorVariantRefresh === "function") {
      this.onColorVariantRefresh(newVariantName);
    }
  }
};
var ids_color_variant_mixin_default = IdsColorVariantMixin;

export {
  ids_color_variant_mixin_default
};
//# sourceMappingURL=ids-chunk-2OCOBBEL-full.js.map
