/*!
 * Enterprise Web Components v1.13.2 (chunk/code split version all components)
 * Copyright (c) 2025 Infor
 */
import {
  debounce
} from "./ids-chunk-UF4RKEE3-full.js";
import {
  requestAnimationTimeout
} from "./ids-chunk-R4JPV7M7-full.js";
import {
  getClosest
} from "./ids-chunk-3BKSN3MI-full.js";

// src/mixins/ids-popup-open-events-mixin/ids-popup-open-events-mixin.ts
var IdsPopupOpenEventsMixin = (superclass) => class extends superclass {
  constructor(...args) {
    super(...args);
  }
  static get attributes() {
    return [...superclass.attributes];
  }
  disconnectedCallback() {
    super.disconnectedCallback?.();
    this.removeOpenEvents();
    this.popupOpenEventsTarget = null;
  }
  /**
   * @property {boolean} hasOpenEvents true if "open" events are currently applied to this component
   */
  hasOpenEvents = false;
  /**
   * @property {IdsPopupElementRef} popupOpenEventsTarget receives the top-level event listener
   *  that will cause the `onOutsideClick` callback to fire
   */
  popupOpenEventsTarget = document.body;
  /**
   * @property {IdsPopupElementRef} currentPopupOpenEventsTarget stores a reference to the event
   *  target to be used for unbinding events (prevents memory leaks if the
   *  event target changes while the Popup is open)
   */
  #currentPopupOpenEventsTarget = null;
  #scrollContainer = null;
  #popupContainer = null;
  /**
   * Attaches some events when the Popupmenu is opened.
   * Call this method from inside your extended component whenever "open" events should be applied.
   * @returns {void}
   */
  addOpenEvents() {
    requestAnimationTimeout(() => {
      this.#popupContainer = getClosest(this, "ids-scroll-container, .scrollable, ids-container, ids-modal, ids-data-grid");
      const nodeName = this.#popupContainer?.nodeName || "";
      switch (nodeName) {
        case "IDS-CONTAINER":
          this.#popupContainer = this.#popupContainer.container;
          break;
        case "IDS-DATA-GRID":
          this.#popupContainer = this.#popupContainer.shadowRoot?.querySelector(".ids-data-grid-wrapper .ids-data-grid") || null;
          break;
        case "IDS-MODAL":
          this.#popupContainer = this.#popupContainer.shadowRoot?.querySelector("ids-popup .ids-modal-container .has-scrollbar") || null;
          break;
        default:
          break;
      }
      if (this.#popupContainer) {
        this.offEvent("scroll.popup");
        this.onEvent("scroll.popup", this.#popupContainer, (e) => {
          this.onOutsideClick?.(e);
        });
      }
      this.offEvent("scroll.document");
      this.onEvent("scroll.document", document, (e) => {
        this.onOutsideClick?.(e);
      });
      this.popupOpenEventsTarget ??= document.body;
      this.offEvent("click.toplevel", this.popupOpenEventsTarget);
      this.onEvent("click.toplevel", this.popupOpenEventsTarget, (e) => {
        this.onOutsideClick?.(e);
      });
      this.#scrollContainer = getClosest(this, "ids-scroll-container, .scrollable, ids-container, ids-modal, ids-data-grid");
      if (this.#scrollContainer) {
        this.offEvent("scroll.toplevel", this.#scrollContainer);
        this.onEvent("scroll.toplevel", this.#scrollContainer, debounce((e) => {
          this.onOutsideClick?.(e);
        }, 50));
      }
      this.hasOpenEvents = true;
      this.#currentPopupOpenEventsTarget = this.popupOpenEventsTarget;
    });
  }
  /**
   * Detaches some events when the Popupmenu is closed.
   * Call this method from inside your extended component whenever "open" events should be removed.
   * @returns {void}
   */
  removeOpenEvents() {
    if (!this.hasOpenEvents) {
      return;
    }
    this.#popupContainer = getClosest(this, "ids-scroll-container, .scrollable, ids-container, ids-modal, ids-data-grid");
    this.offEvent("scroll.popup", this.#popupContainer);
    this.onEvent("scroll.document", document);
    this.offEvent("click.toplevel", this.#currentPopupOpenEventsTarget);
    this.offEvent("scroll.toplevel", this.#scrollContainer);
    this.#scrollContainer = null;
    this.hasOpenEvents = false;
    this.#currentPopupOpenEventsTarget = null;
  }
};
var ids_popup_open_events_mixin_default = IdsPopupOpenEventsMixin;

export {
  ids_popup_open_events_mixin_default
};
//# sourceMappingURL=ids-chunk-DSQC4CQ6-full.js.map
